package nesting.chooseairport;

import org.apache.beehive.netui.pageflow.PageFlowController;
import org.apache.beehive.netui.pageflow.Forward;
import org.apache.beehive.netui.pageflow.annotations.Jpf;

import java.io.Serializable;


@Jpf.Controller(
    nested=true,
    simpleActions={
        @Jpf.SimpleAction(name="begin", path="findairport.jsp"),

        // This action returns to the original page flow, and raises the "chooseAirportCancelled"
        // action.  It is run when the user presses the Cancel button on findairport.jsp or on
        // confirm.jsp.
        @Jpf.SimpleAction(name="cancelSearch", returnAction="chooseAirportCancelled"),

        // This action runs when the user presses the OK button on confirm.jsp.  It returns to the
        // nesting page flow, where it raises the "chooseAirportDone" action.
        @Jpf.SimpleAction(
            name="confirmResults",
            returnAction="chooseAirportDone",
            outputFormBean="_currentResults"
        )
    },
    messageBundles={
        @Jpf.MessageBundle(bundlePath="org.apache.beehive.samples.netui.resources.nesting.chooseairport")
    }
)
public class ChooseAirport extends PageFlowController
{
    /**
     * This is the bean that will be returned to the original page flow.
     */
    private Results _currentResults;

    public Results getCurrentResults()
    {
        return _currentResults;
    }

    /**
     * This action runs when the user presses the Search button on findairport.jsp.  It chooses
     * an airport and forwards to the confirmation page.
     *
     * @jpf:action
     * @jpf:forward name="confirm" path="confirm.jsp"
     */
    @Jpf.Action(
        forwards={
            @Jpf.Forward(name="confirm", path="confirm.jsp")
        },
        validationErrorForward=@Jpf.Forward(name="failure", navigateTo=Jpf.NavigateTo.currentPage)
   )
    protected Forward doSearch(SearchForm form)
    {
        // Pretend we're actually looking up an airport code...
        _currentResults = new Results();
        _currentResults.setAirport("Denver International Airport");
        _currentResults.setAirportCode("DEN");

        return new Forward("confirm");
    }

    /**
     * This is the form bean that works with findairport.jsp.
     */
    public static class SearchForm
        implements Serializable
    {
        private String _searchText;

        @Jpf.ValidatableProperty(
            displayNameKey="displayname.searchtext",
            validateRequired=@Jpf.ValidateRequired()
        )
        public String getSearchText()
        {
            return _searchText;
        }

        public void setSearchText(String st)
        {
            _searchText = st;
        }
    }

    /**
     * This is the bean we'll return to the original page flow.
     */
    public static class Results
        implements Serializable
    {
        private String _airport;
        private String _airportCode;

        public String getAirport()
        {
            return _airport;
        }

        public void setAirport(String airport)
        {
            _airport = airport;
        }

        public String getAirportCode()
        {
            return _airportCode;
        }

        public void setAirportCode(String code)
        {
            _airportCode = code;
        }
    }
}
